==> nextcloud-31.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_reminders/l10n/sr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Подсетници о фајлу",
    "Reminder for {name}" : "Подсетник за {name}",
    "View file" : "Погледај фајл",
    "View folder" : "Погледај фолдер",
    "Files reminder" : "Подсетник фајлова",
    "This files_reminder can work properly." : "Овај files_reminder може да ради како треба.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Да би files_reminder апликација радила како треба, потребна је апликација обавештења. Требало би или да укључите обавештења, или да искључите files_reminder.",
    "Set file reminders" : "Постави подсетнике о фајлу",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Фајл подсетници**\n\nПоставите фајл подсетнике.\n\nНапомена: ако желите да користите апликацију `Фајл подсетници`, обезбедите да је инсталирана и укључена апликација `Обавештења`. Апликација `Обавештења` обезбеђује неопходне API-је уз чију помоћ апликација `Фајл подестници` функционише како треба.",
    "Set reminder for \"{fileName}\"" : "Постави подсетник за „{fileName}”",
    "Set reminder at custom date & time" : "Постави подсетник на произвољни датум и време",
    "Clear reminder" : "Обриши подсетник",
    "Please choose a valid date & time" : "Молимо вас да изаберете исправни датум и време",
    "Reminder set for \"{fileName}\"" : "Подсетник је постављен за „{fileName}”",
    "Failed to set reminder" : "Није успело постављање подсетника",
    "Reminder cleared for \"{fileName}\"" : "Уклоњен је подсетник за „{fileName}”",
    "Failed to clear reminder" : "Није успело брисање подсетника",
    "We will remind you of this file" : "Подсетићемо вас на овај фајл",
    "Cancel" : "Откажи",
    "Set reminder" : "Постави подсетник",
    "Reminder set" : "Подсетник је постављен",
    "Set custom reminder" : "Постави произвољни подсетник",
    "Later today" : "Касније данас",
    "Set reminder for later today" : "Поставља подсетник за касније данас",
    "Tomorrow" : "Сутра",
    "Set reminder for tomorrow" : "Поставља подсетник за сутра",
    "This weekend" : "Овог викенда",
    "Set reminder for this weekend" : "Поставља подсетник за овај викенд",
    "Next week" : "Наредне недеље",
    "Set reminder for next week" : "Поставља подсетник за наредну недељу"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_reminders/l10n/sr.js <==
OC.L10N.register(
    "files_reminders",
    {
    "File reminders" : "Подсетници о фајлу",
    "Reminder for {name}" : "Подсетник за {name}",
    "View file" : "Погледај фајл",
    "View folder" : "Погледај фолдер",
    "Files reminder" : "Подсетник фајлова",
    "The \"files_reminders\" app can work properly." : "Апликација „files_reminder може да ради како треба.",
    "The \"files_reminders\" app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Да би „files_reminder” апликација радила како треба, потребна је апликација обавештења. Требало би или да укључите обавештења, или да искључите files_reminder.",
    "Set file reminders" : "Постави подсетнике о фајлу",
    "**📣 File reminders**\n\nSet file reminders.\n\nNote: to use the `File reminders` app, ensure that the `Notifications` app is installed and enabled. The `Notifications` app provides the necessary APIs for the `File reminders` app to work correctly." : "**📣 Фајл подсетници**\n\nПоставите фајл подсетнике.\n\nНапомена: ако желите да користите апликацију `Фајл подсетници`, обезбедите да је инсталирана и укључена апликација `Обавештења`. Апликација `Обавештења` обезбеђује неопходне API-је уз чију помоћ апликација `Фајл подестници` функционише како треба.",
    "Set reminder for \"{fileName}\"" : "Постави подсетник за „{fileName}”",
    "Clear reminder" : "Обриши подсетник",
    "Please choose a valid date & time" : "Молимо вас да изаберете исправни датум и време",
    "Reminder set for \"{fileName}\"" : "Подсетник је постављен за „{fileName}”",
    "Failed to set reminder" : "Није успело постављање подсетника",
    "Reminder cleared for \"{fileName}\"" : "Уклоњен је подсетник за „{fileName}”",
    "Failed to clear reminder" : "Није успело брисање подсетника",
    "We will remind you of this file" : "Подсетићемо вас на овај фајл",
    "Cancel" : "Откажи",
    "Set reminder" : "Постави подсетник",
    "Reminder set" : "Подсетник је постављен",
    "Later today" : "Касније данас",
    "Set reminder for later today" : "Поставља подсетник за касније данас",
    "Tomorrow" : "Сутра",
    "Set reminder for tomorrow" : "Поставља подсетник за сутра",
    "This weekend" : "Овог викенда",
    "Set reminder for this weekend" : "Поставља подсетник за овај викенд",
    "Next week" : "Наредне недеље",
    "Set reminder for next week" : "Поставља подсетник за наредну недељу",
    "This files_reminder can work properly." : "Овај files_reminder може да ради како треба.",
    "The files_reminder app needs the notification app to work properly. You should either enable notifications or disable files_reminder." : "Да би files_reminder апликација радила како треба, потребна је апликација обавештења. Требало би или да укључите обавештења, или да искључите files_reminder.",
    "Set reminder at custom date & time" : "Постави подсетник на произвољни датум и време",
    "Set custom reminder" : "Постави произвољни подсетник"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
